@@ -102,21 +102,24 @@ class Game:
             if self.board[self.board_size - 1][col] and self.board[self.board_size - 1][col].team == Team.WHITE: white += 1
 
         # End the game in the case of three turns where nothing changes
-        if self.round >= 4 and self.board_states[-1] == self.board_states[-2] == self.board_states[-3]:
-            self.round = self.max_rounds + 1
+##        if self.round >= 4 and self.board_states[-1] == self.board_states[-2] == self.board_states[-3]:
+##            self.round = self.max_rounds + 1
         
         if self.round > self.max_rounds:
             self.running = False
-            if white == black:
-                piece_diff = sum(sum([1 if piece.team == Team.WHITE else -1 for piece in row if piece]) for row in self.board)
-                if piece_diff > 0:
-                    self.winner = Team.WHITE
-                elif piece_diff < 0:
-                    self.winner = Team.BLACK
-                else:
-                    self.winner = random.choice([Team.WHITE, Team.BLACK])
+            i = 0
+            while white == black and i < self.board_size - 1:
+                i += 1
+                white, black = 0, 0
+                for col in range(self.board_size):
+                    if self.board[i][col] and self.board[i][col].team == Team.BLACK: black += 1
+                    if self.board[self.board_size - 1 - i][col] and self.board[self.board_size - 1 - i][col].team == Team.WHITE: white += 1
+            if white > black:
+                self.winner = Team.WHITE
+            elif white < black:
+                self.winner = Team.BLACK
             else:
-                self.winner = Team.WHITE if white > black else Team.BLACK
+                self.winner = random.choice([Team.WHITE, Team.BLACK])
 
         if white >= (self.board_size + 1) // 2:
             self.running = False
